# Configuration directory

This directory contains "configuration" data, i.e. data which helps with and
guides the conversion of the raw data to CLDF. Recognized files in this directory
are

See https://github.com/lexibank/lexibank/blob/master/dataset.md#etc